pub enum ForwardReason {
MatchedForwardIncoming,
MatchedForwardCached,
CompensatoryReply,
KeyExchangeInitiation,
KeyExchangeReply,
}Expand description
Forward reason.
Variants
MatchedForwardIncoming
Forwarded incoming message X using matched message header addresses.
MatchedForwardCached
Forwarded matched cached message Y using incoming header addresses.
CompensatoryReply
Compensatory response chosen when best peer already sent X.
KeyExchangeInitiation
Key-exchange protocol initiation.
KeyExchangeReply
Key-exchange protocol reply.